.. _homogenization-nonlinear_hyperelastic_mM:

homogenization/nonlinear_hyperelastic_mM.py
===========================================

**Description**


Homogenized nonlinear hyperelastic material with evolving microstructure
deformation in each macroscopic quadrature point.

Run in parallel using::

  mpiexec -n 4 sfepy-run --app=bvp-mM --debug-mpi sfepy/examples/homogenization/nonlinear_hyperelastic_mM.py


.. image:: /../doc/images/gallery/homogenization-nonlinear_hyperelastic_mM.png


:download:`source code </../sfepy/examples/homogenization/nonlinear_hyperelastic_mM.py>`

.. literalinclude:: /../sfepy/examples/homogenization/nonlinear_hyperelastic_mM.py

